@@ -16,19 +16,21 @@ sub inquire {
     my $mhead = shift // return undef;
     my $mbody = shift // return undef;
 
-    return undef unless index($mhead->{'subject'}, 'Returned Mail: ') == 0;
-    return undef unless index($mhead->{'from'}, '"Mail Deliver System" ') == 0;
+    my $proceedsto = 0;
+       $proceedsto = 1 if index($mhead->{'subject'}, 'Returned Mail: ') == 0;
+       $proceedsto = 1 if index($mhead->{'subject'}, 'Mail Delivery Failure') == 0;
+       $proceedsto = 1 if Sisimai::String->aligned(\$mhead->{'from'}, ['"Mail Deliver', 'System" ']);
+    return undef unless $proceedsto;
 
     state $indicators = __PACKAGE__->INDICATORS;
-    state $boundaries = ['Received: from '];
-    state $markingsof = { 'message' => ['The original message was received at '] };
+    state $boundaries = ['Content-Type: message/rfc822', 'Received: from '];
+    state $markingsof = {'message' => ['The original message was received at ']};
 
-    my $dscontents = [__PACKAGE__->DELIVERYSTATUS];
+    my $dscontents = [__PACKAGE__->DELIVERYSTATUS]; my $v = undef;
     my $emailparts = Sisimai::RFC5322->part($mbody, $boundaries);
     my $readcursor = 0;     # (Integer) Points the current cursor position
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
     my $datestring = '';    # (String) Date string
-    my $v = undef;
 
     for my $e ( split("\n", $emailparts->[0]) ) {
         # Read error messages and delivery status lines from the head of the email to the previous
@@ -38,8 +40,7 @@ sub inquire {
             $readcursor |= $indicators->{'deliverystatus'} if index($e, $markingsof->{'message'}->[0]) == 0;
             next;
         }
-        next unless $readcursor & $indicators->{'deliverystatus'};
-        next unless length $e;
+        next if ($readcursor & $indicators->{'deliverystatus'}) == 0 || $e eq "";
 
         # The original message was received at Thu, 29 Apr 2010 23:34:45 +0900 (JST)
         # from shironeko@example.jp
@@ -73,7 +74,7 @@ sub inquire {
         $e->{'diagnosis'} = Sisimai::String->sweep($e->{'diagnosis'});
         $e->{'date'}      = $datestring || '';
     }
-    return { 'ds' => $dscontents, 'rfc822' => $emailparts->[1] };
+    return {"ds" => $dscontents, "rfc822" => $emailparts->[1]};
 }
 
 1;
@@ -113,7 +114,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2021,2023,2024 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2021,2023-2025 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
