@@ -15,37 +15,32 @@ state $Fields1894 = Sisimai::RFC1894->FIELDINDEX;
 state $Fields5322 = Sisimai::RFC5322->FIELDINDEX;
 state $Fields5965 = Sisimai::RFC5965->FIELDINDEX;
 state $FieldTable = { map { lc $_ => $_ } ($Fields1894->@*, $Fields5322->@*, $Fields5965->@*) };
-state $ReplacesAs = { 'Content-Type' => [['message/xdelivery-status', 'message/delivery-status']] };
-state $Boundaries = ['Content-Type: message/rfc822', 'Content-Type: text/rfc822-headers'];
+state $Boundaries = ["Content-Type: message/rfc822", "Content-Type: text/rfc822-headers"];
+state $MediaTypes = [
+    ["message/xdelivery-status",                "message/delivery-status"],
+    ["message/disposition-notification",        "message/delivery-status"],
+    ["message/global-delivery-status",          "message/delivery-status"],
+    ["message/global-disposition-notification", "message/delivery-status"],
+    ["message/global-delivery-status",          "message/delivery-status"],
+    ["message/global-headers",                  "text/rfc822-headers"],
+    ["message/global",                          "message/rfc822"],
+];
 
-my $ToBeLoaded = [];
 my $TryOnFirst = [];
 
 sub rise {
     # Constructor of Sisimai::Message
     # @param         [Hash] argvs   Email text data
     # @options argvs [String] data  Entire email message
-    # @options argvs [Array]  load  User defined MTA module list
-    # @options argvs [Array]  order The order of MTA modules
     # @options argvs [Code]   hook  Reference to callback method
     # @return        [Hash]         Structured email data
     #                [Undef]        If each value of the arguments are missing
     my $class = shift;
     my $argvs = shift            || return undef;
     my $email = $argvs->{'data'} || return undef;
-    my $thing = { 'from' => '', 'header' => {}, 'rfc822' => '', 'ds' => [], 'catch' => undef };
+    my $thing = {'from' => '', 'header' => {}, 'rfc822' => '', 'ds' => [], 'catch' => undef};
     my $param = {};
 
-    # 0. Load specified MTA modules
-    for my $e ('load', 'order') {
-        # Order of MTA modules
-        next unless exists $argvs->{ $e };
-        next unless ref $argvs->{ $e } eq 'ARRAY';
-        next unless scalar $argvs->{ $e }->@*;
-        $param->{ $e } = $argvs->{ $e };
-    }
-    $ToBeLoaded = __PACKAGE__->load(%$param);
-
     my $aftersplit = undef;
     my $beforefact = undef;
     my $parseagain = 0;
@@ -70,20 +65,21 @@ sub rise {
             if( $p1 > -1 ) {
                 # Delete quoted strings, quote symbols(>)
                 $cq = Sisimai::String->sweep(substr($cq, index($cq, ':') + 1,));
-                s/^[>]+[ ]//gm, s/^[>]$//gm for $aftersplit->[2];
+                s/^[>][ ]//gm, s/^[>]$//gm for $aftersplit->[2];
             }
             $thing->{'header'}->{'subject'} = $cq;
         }
 
         # 4. Rewrite message body for detecting the bounce reason
         $TryOnFirst = Sisimai::Order->make($thing->{'header'}->{'subject'});
-        $param = { 'hook' => $argvs->{'hook'} || undef, 'mail' => $thing, 'body' => \$aftersplit->[2] };
+        $param = {'hook' => $argvs->{'hook'} || undef, 'mail' => $thing, 'body' => \$aftersplit->[2]};
         last if $beforefact = __PACKAGE__->sift(%$param);
         last unless grep { index($aftersplit->[2], $_) > -1 } @$Boundaries;
 
         # 5. Try to sift again
         #    There is a bounce message inside of mutipart/*, try to sift the first message/rfc822
-        #    part as a entire message body again.
+        #    part as a entire message body again. rfc3464/1086-a847b090.eml is the email but the
+        #    results decodd by sisimai are unstable.
         $parseagain++;
         $email =  Sisimai::RFC5322->part(\$aftersplit->[2], $Boundaries, 1)->[1];
         $email =~ s/\A[\r\n\s]+//m;
@@ -99,48 +95,6 @@ sub rise {
     return $thing;
 }
 
-sub load {
-    # Load MTA modules which specified at 'order' and 'load' in the argument
-    # @param         [Hash] argvs       Module information to be loaded
-    # @options argvs [Array]  load      User defined MTA module list
-    # @options argvs [Array]  order     The order of MTA modules
-    # @return        [Array]            Module list
-    # @since v4.20.0
-    my $class = shift;
-    my $argvs = { @_ };
-
-    my @modulelist;
-    my $tobeloaded = [];
-
-    for my $e ('load', 'order') {
-        # The order of MTA modules specified by user
-        next unless exists $argvs->{ $e };
-        next unless ref $argvs->{ $e } eq 'ARRAY';
-        next unless scalar $argvs->{ $e }->@*;
-
-        push @modulelist, $argvs->{'order'}->@* if $e eq 'order';
-        next unless $e eq 'load';
-
-        # Load user defined MTA module
-        for my $v ( $argvs->{'load'}->@* ) {
-            # Load user defined MTA module
-            eval {
-                (my $modulepath = $v) =~ s|::|/|g;
-                require $modulepath.'.pm';
-            };
-            next if $@;
-            push @$tobeloaded, $v;
-        }
-    }
-
-    for my $e ( @modulelist ) {
-        # Append the custom order of MTA modules
-        next if grep { $e eq $_ } @$tobeloaded;
-        push @$tobeloaded, $e;
-    }
-    return $tobeloaded;
-}
-
 sub part {
     # Divide email data up headers and a body part.
     # @param         [String] email  Email data
@@ -153,14 +107,14 @@ sub part {
     $$email =~ s/\A\s+//m;
     $$email =~ s/\r\n/\n/gm if rindex($$email, "\r\n") > -1;
 
-    ($parts->[1], $parts->[2]) = split(/\n\n/, $$email, 2);
-    return undef unless $parts->[1];
-    return undef unless $parts->[2];
+    ($parts->[1], $parts->[2]) = split(/\n\n/, $$email, 2); $parts->[2] ||= "";
+    return undef if $parts->[1] eq "" || $parts->[2] eq "";
 
     if( substr($parts->[1], 0, 5) eq 'From ' ) {
         # From MAILER-DAEMON Tue Feb 11 00:00:00 2014
         $parts->[0] =  [split(/\n/, $parts->[1], 2)]->[0];
         $parts->[0] =~ y/\r\n//d;
+
     } else {
         # Set pseudo UNIX From line
         $parts->[0] =  'MAILER-DAEMON Tue Feb 11 00:00:00 2014';
@@ -193,21 +147,19 @@ sub makemap {
 
     # Select and convert all the headers in $argv0. The following regular expression is based on
     # https://gist.github.com/xtetsuji/b080e1f5551d17242f6415aba8a00239
-    my $firstpairs = { $$argv0 =~ /^([\w-]+):[ ]*(.*?)\n(?![\s\t])/gms };
-    my $headermaps = { 'subject' => '' };
+    my $firstpairs = {$$argv0 =~ /^([\w-]+):[ ]*(.*?)\n(?![\s\t])/gms};
+    my $headermaps = {'subject' => ''};
        $headermaps->{ lc $_ } = $firstpairs->{ $_ } for keys %$firstpairs;
     my $receivedby = [];
 
     for my $e ( values %$headermaps ) { s/\n\s+/ /, y/\t / /s for $e }
-
     if( index($$argv0, "\nReceived:") > 0 || index($$argv0, "Received:") == 0 ) {
         # Capture values of each Received: header
         my $re = [$$argv0 =~ /^Received:[ ]*(.*?)\n(?![\s\t])/gms];
         for my $e ( @$re ) {
             # 1. Exclude the Received header including "(qmail ** invoked from network)".
             # 2. Convert all consecutive spaces and line breaks into a single space character.
-            next if index($e, ' invoked by uid')       > 0;
-            next if index($e, ' invoked from network') > 0;
+            next if index($e, Sisimai::RFC5322->woReceived->[0]) > 0 || index($e, Sisimai::RFC5322->woReceived->[1]) > 0;
 
             $e =~ s/\n\s+/ /;
             $e =~ y/\n\t / /s;
@@ -233,7 +185,7 @@ sub makemap {
         # MIME-Encoded subject field or ASCII characters only
         my $r = [];
         if( Sisimai::RFC2045->is_encoded(\$headermaps->{'subject'}) ) {
-            # split the value of Subject by $borderline
+            # split the Subject: field by " "
             for my $v ( split(/ /, $headermaps->{'subject'}) ) {
                 # Insert value to the array if the string is MIME encoded text
                 push @$r, $v if Sisimai::RFC2045->is_encoded(\$v);
@@ -255,99 +207,94 @@ sub tidy {
     my $class = shift;
     my $argv0 = shift || return '';
     my $email = '';
+    my @lines = split("\n", $$argv0);
+    my $index = -1;
 
-    return '' unless $argv0;
-    return '' unless length $$argv0;
-
-    for my $e ( split("\n", $$argv0) ) {
+    for my $e ( @lines ) {
         # Find and tidy up fields defined in RFC5322, RFC1894, and RFC5965
         # 1. Find a field label defined in RFC5322, RFC1894, or RFC5965 from this line
         my $p0 = index($e, ':');
-        my $cf = substr(lc $e, 0, $p0);
+        my $cf = substr(lc $e, 0, $p0); chop $cf if substr($cf, -1, 1) eq ' ';
+        my $fn = $FieldTable->{ $cf } || '';
 
-        unless( $FieldTable->{ $cf } ) {
-            # There is neither ":" character nor a field listed in @fieldindex
-            $email .= $e."\n";
-            next;
-        }
+        # There is neither ":" character nor the field listed in $FieldTable
+        $index++;
+        if( $fn eq '' ){ $email .= $e."\n"; next }
 
-        # 2. There is a field label defined in RFC5322, RFC1894, or RFC5965 from this line.
-        #    Code below replaces the field name with a valid name listed in @fieldindex when
-        #    the field name does not match with a valid name.
-        #    - Before: Message-id: <...>
-        #    - After:  Message-Id: <...>
-        my $fieldlabel = $FieldTable->{ $cf };
-        my $substring0 = substr($e, 0, $p0);
-        substr($e, 0, $p0, $fieldlabel) if $substring0 ne $fieldlabel;
-
-        # 3. There is no " " (space character) immediately after ":"
-        #    - before: Content-Type:text/plain
-        #    - After:  Content-Type: text/plain
-        $substring0 = substr($e, $p0 + 1, 1);
-        substr($e, $p0, 1, ': ') if $substring0 ne ' ';
-
-        # 4. Remove redundant space characters after ":"
-        while(1) {
-            # - Before: Message-Id:    <...>
-            # - After:  Message-Id: <...>
-            last unless $p0 + 2 < length($e);
-            last unless substr($e, $p0 + 2, 1) eq ' ';
-            substr($e, $p0 + 2, 1, '');
-        }
-
-        # 5. Tidy up a sub type of each field defined in RFC1894 such as Reporting-MTA: DNS;...
-        my $p1 = index($e, ';');
+        # 2. Tidy up a sub type of each field defined in RFC1894 such as Reporting-MTA: DNS;...
+        my $ab = [];
+        my $bf = substr($e, $p0 + 1,);
+        my $p1 = index($bf, ';');
         while(1) {
             # Such as Diagnostic-Code, Remote-MTA, and so on
             # - Before: Diagnostic-Code: SMTP;550 User unknown
             # - After:  Diagnostic-Code: smtp; 550 User unknown
-            last unless $p1 > $p0;
-            last unless grep { $fieldlabel eq $_ } (@$Fields1894, 'Content-Type');
+            last unless grep { $fn eq $_ } (@$Fields1894, 'Content-Type');
 
-            $substring0 = substr($e, $p0 + 2, $p1 - $p0 - 1);
-            substr($e, $p0 + 2, length($substring0), sprintf("%s ", lc $substring0));
-            last;
-        }
+            if( $p1 > 0 ) {
+                # The field including one or more ";"
+                for my $f (split(';', $bf)) {
+                    # 2-1. Trim leading and trailing space characters from the current buffer
+                    while( index($f, ' ') == 0 )    { $f = substr($f, 1,) }
+                    while( substr($f, -1, 1) eq ' '){ $f = substr($f, 0, length($f) - 1) }
+                    my $ps = '';
 
-        # 6. Remove redundant space characters after ";"
-        while(1) {
-            # - Before: Diagnostic-Code: SMTP;      550 User unknown
-            # - After:  Diagnostic-Code: SMTP; 550 User unknown
-            last unless $p1 + 2 < length($e);
-            last unless substr($e, $p1 + 2, 1) eq ' ';
-            substr($e, $p1 + 2, 1, '');
-        }
+                    # 2-2. Convert some parameters to the lower-cased string
+                    while(1) {
+                        # For example,
+                        # - Content-Type: Message/delivery-status => message/delivery-status
+                        # - Content-Type: Charset=UTF8            => charset=utf8
+                        # - Reporting-MTA: DNS; ...               => dns
+                        # - Final-Recipient: RFC822; ...          => rfc822
+                        last if index($f, ' ') > 0;
 
-        # 7. Tidy up a value, and a parameter of Content-Type: field
-        while(1) {
-            # Replace the value of "Content-Type" field
-            last unless exists $ReplacesAs->{ $fieldlabel };
-            my $p2 = 0;
+                        my $p2 = index($f, '='); if( $p2 > 0 ) {
+                            # charset=, boundary=, and other pairs divided by "="
+                            $ps = lc substr($f, 0, $p2);
+                            substr($f, 0, $p2, $ps);
+                        }
+                        $f = lc $f if $ps ne 'boundary';
+                        $f = 'rfc822' if $f eq 'rfc/822';
+                        last;
+                    }
+                    push @$ab, $f;
+                }
 
-            for my $f ( $ReplacesAs->{ $fieldlabel }->@* ) {
-                # Content-Type: message/xdelivery-status
-                $p2 = index($e, $f->[0]);
-                next unless $p2 > 1;
+                if( $fn eq 'Diagnostic-Code' ) {
+                    # Diagnostic-Code: x-unix;
+                    #   /var/email/kijitora/Maildir/tmp/1000000000.A000000B00000.neko22:
+                    #   Disk quota exceeded
+                    push @$ab, '' if scalar @$ab == 1 && index($lines[$index + 1], " ") == 0;
+                }
+                $bf = join('; ', @$ab); $ab = []; # Insert " " (space characer) immediately after ";"
 
-                substr($e, $p2, length $f->[0], $f->[1]);
-                $p1 = index($e, ';');
-                last;
+            } else {
+                # There is no ";" in the field
+                # Arrival-Date, Last-Attempt-Date
+                # X-Original-Message-ID
+                last if index($fn, '-Date') > 0 || index($fn, '-Message-ID') > 0;
+                $bf = lc $bf;
             }
-
-            # A parameter name of Content-Type field should be a lower-cased string
-            # - Before: Content-Type: text/plain; CharSet=ascii; Boundary=...
-            # - After:  Content-Type: text/plain; charset=ascii; boundary=...
-            last unless $fieldlabel eq 'Content-Type';
-            $p2 = index($e, '=');
-            last unless $p2 > 0;
-            last unless $p2 > $p1;
-
-            $substring0 = substr($e, $p1 + 2, $p2 - $p1 - 2); 
-            substr($e, $p1 + 2, $p2 - $p1 - 2, lc $substring0);
-
             last;
         }
-        $email .= $e."\n";
+
+        # 3. Tidy up a value, and a parameter of Content-Type: field
+        if( $fn eq "Content-Type" ) {
+            # Replace the value of "Content-Type" field
+            for my $f ( @$MediaTypes ) {
+                # - Before: Content-Type: message/xdelivery-status; ...
+                # - After:  Content-Type: message/delivery-status; ...
+                $p1 = index($bf, $f->[0]); next if $p1 < 0;
+                substr($bf, $p1, length $f->[0], $f->[1]);
+            }
+        }
+
+        # 4. Concatenate the field name and the field value
+        for my $f ( split(' ', $bf) ) {
+            # Remove redundant space characters
+            push @$ab, $f if length $f > 0;
+        }
+        $email .= sprintf("%s: %s\n", $fn, join(' ', @$ab));
     }
 
     $email .= "\n" if substr($email, -2, 2) ne "\n\n";
@@ -369,8 +316,8 @@ sub sift {
     my $argvs = { @_ };
 
     my $mailheader = $argvs->{'mail'}->{'header'} || return undef;
-    my $bodystring = $argvs->{'body'} || return undef;
-    my $hookmethod = $argvs->{'hook'} || undef;
+    my $bodystring = $argvs->{'body'}             || return undef;
+    my $hookmethod = $argvs->{'hook'}             || undef;
     my $havecaught = undef;
 
     state $defaultset = Sisimai::Order->another;
@@ -404,14 +351,14 @@ sub sift {
     } elsif( index($mesgformat, 'multipart/') == 0 ) {
         # In case of Content-Type: multipart/*
         my $p = Sisimai::RFC2045->makeflat($mailheader->{'content-type'}, $bodystring);
-        $bodystring = $p if length $$p;
+        $bodystring = $p if defined $p && length $$p;
     }
     $$bodystring =~ tr/\r//d;
     $$bodystring =~ s/\t/ /g;
 
     if( ref $hookmethod eq 'CODE' ) {
         # Call hook method
-        my $p = { 'headers' => $mailheader, 'message' => $$bodystring };
+        my $p = {'headers' => $mailheader, 'message' => $$bodystring};
         eval { $havecaught = $hookmethod->($p) };
         warn sprintf(" ***warning: Something is wrong in hook method 'hook': %s", $@) if $@;
     }
@@ -420,21 +367,11 @@ sub sift {
     my $havesifted = undef;
     my $modulename = '';
     DECODER: while(1) {
-        # 1. User-Defined Module
-        # 2. MTA Module Candidates to be tried on first
-        # 3. Sisimai::Lhost::*
-        # 4. Sisimai::RFC3464
-        # 5. Sisimai::ARF
-        # 6. Sisimai::RFC3834
-        USER_DEFINED: for my $r ( @$ToBeLoaded ) {
-            # Call user defined MTA modules
-            next if exists $haveloaded->{ $r };
-            $havesifted = $r->inquire($mailheader, $bodystring);
-            $haveloaded->{ $r } = 1;
-            $modulename = $r;
-            last(DECODER) if $havesifted;
-        }
-
+        # 1. MTA Module Candidates to be tried on first
+        # 2. Sisimai::Lhost::*
+        # 3. Sisimai::RFC3464
+        # 4. Sisimai::ARF
+        # 5. Sisimai::RFC3834
         TRY_ON_FIRST_AND_DEFAULTS: for my $r ( @$TryOnFirst, @$defaultset ) {
             # Try MTA module candidates
             next if exists $haveloaded->{ $r };
@@ -445,36 +382,28 @@ sub sift {
             last(DECODER) if $havesifted;
         }
 
-        unless( $haveloaded->{'Sisimai::RFC3464'} ) {
-            # When the all of Sisimai::Lhost::* modules did not return bounce data, call Sisimai::RFC3464;
-            require Sisimai::RFC3464;
-            $havesifted = Sisimai::RFC3464->inquire($mailheader, $bodystring);
-            $modulename = 'RFC3464';
-            last(DECODER) if $havesifted;
-        }
+        # When the all of Sisimai::Lhost::* modules did not return bounce data, call Sisimai::RFC3464;
+        require Sisimai::RFC3464;
+        $havesifted = Sisimai::RFC3464->inquire($mailheader, $bodystring);
+        if( $havesifted ){ $modulename = 'RFC3464'; last(DECODER) }
 
-        unless( $haveloaded->{'Sisimai::ARF'} ) {
-            # Feedback Loop message
-            require Sisimai::ARF;
-            $havesifted = Sisimai::ARF->inquire($mailheader, $bodystring);
-            last(DECODER) if $havesifted;
-        }
+        # Feedback Loop message
+        require Sisimai::ARF;
+        $havesifted = Sisimai::ARF->inquire($mailheader, $bodystring);
+        if( $havesifted ){ $modulename = "ARF"; last(DECODER) }
+
+        # Try to sift the message as auto reply message defined in RFC3834
+        require Sisimai::RFC3834;
+        $havesifted = Sisimai::RFC3834->inquire($mailheader, $bodystring);
+        if( $havesifted ){ $modulename = 'RFC3834'; last(DECODER) }
 
-        unless( $haveloaded->{'Sisimai::RFC3834'} ) {
-            # Try to sift the message as auto reply message defined in RFC3834
-            require Sisimai::RFC3834;
-            $havesifted = Sisimai::RFC3834->inquire($mailheader, $bodystring);
-            $modulename = 'RFC3834';
-            last(DECODER) if $havesifted;
-        }
         last; # as of now, we have no sample email for coding this block
 
     } # End of while(DECODER)
     return undef unless $havesifted;
 
     $havesifted->{'catch'} = $havecaught;
-    $modulename =~ s/\A.+:://;
-    $_->{'agent'} ||= $modulename for $havesifted->{'ds'}->@*;
+    $modulename =~ s/\A.+:://; $_->{'agent'} ||= $modulename for $havesifted->{'ds'}->@*;
     return $havesifted;
 }
 
@@ -518,14 +447,6 @@ C<rise()> method is a constructor of C<Sisimai::Message>
     my $mailtxt = 'Entire email text';
     my $message = Sisimai::Message->rise('data' => $mailtxt);
 
-If you have implemented a custom MTA module and use it, set the value of C<load> in the argument of
-this method as an array reference like following code:
-
-    my $message = Sisimai::Message->rise(
-                        'data' => $mailtxt,
-                        'load' => ['Your::Custom::MTA::Module']
-                  );
-
 =head1 INSTANCE METHODS
 
 =head2 C<B<(from)>>
@@ -567,7 +488,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2024 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2025 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
