@@ -38,7 +38,7 @@ sub make {
         'failure-delivery' => ['Sisimai::Lhost::X2'],
         'failure-notice'   => ['Sisimai::Lhost::qmail', 'Sisimai::Lhost::mFILTER', 'Sisimai::Lhost::Activehunter'],
         'loop-alert'       => ['Sisimai::Lhost::FML'],
-        'mail-could'       => ['Sisimai::Lhost::InterScanMSS'],
+        'mail-could'       => ['Sisimai::Lhost::TrendMicro'],
         'mail-delivery'    => [
             'Sisimai::Lhost::Exim',
             'Sisimai::Lhost::DragonFly',
@@ -53,6 +53,7 @@ sub make {
         'non-recapitabile'  => ['Sisimai::Lhost::Exchange2007'],
         'non-remis'         => ['Sisimai::Lhost::Exchange2007'],
         'notice'            => ['Sisimai::Lhost::Courier'],
+        'postmaster-email'  => ['Sisimai::Lhost::Mimecast'],
         'postmaster-notify' => ['Sisimai::Lhost::Sendmail'],
         'returned-mail'     => [
             'Sisimai::Lhost::Sendmail',
@@ -62,7 +63,7 @@ sub make {
         ],
         'there-was'     => ['Sisimai::Lhost::X6'],
         'undeliverable' => ['Sisimai::Lhost::Exchange2007', 'Sisimai::Lhost::Exchange2003'],
-        'undeliverable-mail'    => ['Sisimai::Lhost::MailMarshalSMTP', 'Sisimai::Lhost::IMailServer'],
+        'undeliverable-mail'    => ['Sisimai::Lhost::MailMarshal', 'Sisimai::Lhost::IMailServer'],
         'undeliverable-message' => ['Sisimai::Lhost::Notes', 'Sisimai::Lhost::Verizon'],
         'undelivered-mail'      => ['Sisimai::Lhost::Postfix', 'Sisimai::Lhost::Zoho'],
         'warning'               => ['Sisimai::Lhost::Sendmail', 'Sisimai::Lhost::Exim'],
@@ -92,7 +93,7 @@ sub another {
         'Sisimai::Lhost::Sendmail',
         'Sisimai::Lhost::Exchange2007',
         'Sisimai::Lhost::Exchange2003',
-        'Sisimai::Lhost::InterScanMSS',
+        'Sisimai::Lhost::TrendMicro',
         'Sisimai::Lhost::KDDI',
         'Sisimai::Lhost::FML',
         'Sisimai::Lhost::Verizon',
@@ -119,7 +120,7 @@ sub another {
         'Sisimai::Lhost::Activehunter',
         'Sisimai::Lhost::MailFoundry',
         'Sisimai::Lhost::GoogleGroups',
-        'Sisimai::Lhost::MailMarshalSMTP',
+        'Sisimai::Lhost::MailMarshal',
         'Sisimai::Lhost::V5sendmail',
         'Sisimai::Lhost::EZweb',
         'Sisimai::Lhost::Biglobe',
