@@ -34,7 +34,7 @@ sub match {
         'specified domain is not allowed',
         "that domain isn't in my list of allowed rcpthost",
         'this system is not configured to relay mail',
-        'unable to relay for',
+        'unable to relay ',
         "we don't handle mail for",
     ];
     return 1 if grep { rindex($argv1, $_) > -1 } @$index;
