@@ -22,9 +22,8 @@ sub true  {
     # @since v4.1.28
     # @see http://www.ietf.org/rfc/rfc2822.txt
     my $class = shift;
-    my $argvs = shift // return undef;
+    my $argvs = shift // return 0; return 0 unless $argvs->{'deliverystatus'};
 
-    return undef unless $argvs->{'deliverystatus'};
     return 1 if $argvs->{'reason'} eq 'onhold';
     return 1 if (Sisimai::SMTP::Status->name($argvs->{'deliverystatus'}) || '') eq 'onhold';
     return 0
@@ -75,7 +74,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2016,2018,2020,2021,2024 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2016,2018,2020,2021,2024,2025 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
