@@ -5,8 +5,8 @@ use warnings;
 
 sub text  { 'undefined' }
 sub description { 'Sisimai could not detect an error reason' }
-sub match { return undef }
-sub true  { return undef }
+sub match { return 0 }
+sub true  { return 0 }
 1;
 
 __END__
@@ -37,11 +37,11 @@ C<text()> method returns the fixed string C<undefined>.
 
 =head2 C<B<match(I<string>)>>
 
-C<match()> method always return C<undef>
+C<match()> method always return C<0>
 
 =head2 C<B<true(I<Sisimai::Fact>)>>
 
-C<true()> method always return C<undefZ>
+C<true()> method always return C<0>
 
 =head1 AUTHOR
 
@@ -49,7 +49,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2016,2020,2021,2024 azumakuniyuki, All rights reserved.
+Copyright (C) 2016,2020,2021,2024,2025 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
