@@ -10,13 +10,13 @@ sub find {
     # @return   [String]                The bounce reason at Mimecast
     # @since v4.25.15
     my $class = shift;
-    my $argvs = shift // return undef;
+    my $argvs = shift // return "";
     return '' unless $argvs->{'diagnosticcode'};
     return '' unless Sisimai::SMTP::Reply->test($argvs->{'replycode'});
 
     state $messagesof = {
-        # https://community.mimecast.com/s/article/Mimecast-SMTP-Error-Codes-842605754
-        # https://community.mimecast.com/s/article/email-security-cloud-gateway-mimecast-smtp-error-codes
+        # - https://community.mimecast.com/s/article/email-security-cloud-gateway-mimecast-smtp-error-codes
+        # - https://mimecastsupport.zendesk.com/hc/en-us/articles/34000709564691-Policies-Mimecast-SMTP-Error-Codes
         'authfailure' => [
             # - The inbound message has been rejected because the originated IP address isn't list-
             #   ed in the published SPF records for the sending domain.
@@ -55,6 +55,8 @@ sub find {
             [550, 'local ct ip reputation - (reject)'],
         ],
         'blocked' => [
+            # - Sender address blocked.
+            #   A Blocked Senders Policy has blocked the sender's IP address.
             # - The sender's IP address has been blocked by a Blocked Senders Policy.
             # - Remove the entry from the policy.
             [421, 'sender address blocked'],
@@ -83,9 +85,17 @@ sub find {
             #   if rejected, causing the journal queue to grow.
             # - Check to confirm there are no significant time discrepancies on the mail server.
             #   Discontinue journaling old messages past the expiry threshold.
-            [550, 'Journal messages past the expiration'],
+            [550, 'journal messages past the expiration'],
         ],
         'failedstarttls' => [
+            # - SMTP inbound TLS has been enabled but no SSL certificate (or no valid certificate)
+            #   has been selected to be used. 
+            # - Delete or change the Secure Receipt or Secure Delivery policy enforcing TLS.
+            #   Alternatively, ensure the certificates on the mail server haven't expired.
+            #   If using a proxy server, ensure it isn't intercepting the traffic and modifying
+            #   encryption parameters.
+            ["454", "tls not available due to temporary reason"],
+
             # - This email has been sent using SMTP, but TLS is required by policy.
             # - Delete or change the Secure Receipt or Secure Delivery policy enforcing TLS.
             #   Alternatively, ensure the certificates on the mail server haven't expired. If using
@@ -208,6 +218,19 @@ sub find {
             [550, 'submitter failed to disabled'],
             [550, 'submitter failed to authenticate'],
         ],
+        'spamdetected' => [
+            # - A signature was detected that could either be a virus, or a spam score over the
+            #   maximum threshold. The spam score isn't available in the Administration Console. If
+            #   you aren't a Mimecast customer but have emails rejected with this error code, con-
+            #   tact the recipient to adjust their configuration and permit your address. If unsuc-
+            #   cessful, your IT department can submit a request to review these email rejections
+            #   via our Sender Feedback form.
+            # - Anti-virus checks cannot be bypassed. Contact the sender to see if they can stop
+            #   these messages from being blocked. Anti-spam checks can be bypassed using a Per-
+            #   mitted Senders or Auto Allow policy. Rejected emails can be viewed in your Outbound
+            #   Activity and searching for the required email address.
+            [554, 'email rejected due to security policies'],
+        ],
         'systemerror' => [
             # - The Mimecast server is under maximum load.
             # - No action is required from the end-user. The message will retry 30 times and when
@@ -273,19 +296,6 @@ sub find {
             # - The sender must resend the message to a valid internal recipient address.
             [550, 'invalid recipient'],
         ],
-        'virusdetected' => [
-            # - A signature was detected that could either be a virus, or a spam score over the
-            #   maximum threshold. The spam score isn't available in the Administration Console. If
-            #   you aren't a Mimecast customer but have emails rejected with this error code, con-
-            #   tact the recipient to adjust their configuration and permit your address. If unsuc-
-            #   cessful, your IT department can submit a request to review these email rejections
-            #   via our Sender Feedback form.
-            # - Anti-virus checks cannot be bypassed. Contact the sender to see if they can stop
-            #   these messages from being blocked. Anti-spam checks can be bypassed using a Per-
-            #   mitted Senders or Auto Allow policy. Rejected emails can be viewed in your Outbound
-            #   Activity and searching for the required email address.
-            [554, 'email rejected due to security policies'],
-        ],
     };
 
     my $issuedcode = lc $argvs->{'diagnosticcode'} // 0;
@@ -336,7 +346,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2022-2024 azumakuniyuki, All rights reserved.
+Copyright (C) 2022-2025 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
